@@ -1,7 +1,7 @@
 """
 Type annotations for iot-data service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/literals/)
 
 Usage::
 
@@ -25,6 +25,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -148,6 +149,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -346,3 +348,23 @@ ResourceServiceName = Literal[
     "sqs",
 ]
 PaginatorName = Literal["list_retained_messages"]
+RegionName = Literal[
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
